==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/NotaOdplatnosc.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.RodzajZadluzenia;
import pl.topteam.dps.enums.StatusNotyOdplatnosc;
import pl.topteam.dps.enums.TypNotyOdplatnosc;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class NotaOdplatnosc extends GenericDPSObject {
    /**
     * NOTA_ODPLATNOSC.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * NOTA_ODPLATNOSC.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long instytucjaId;

    /**
     * NOTA_ODPLATNOSC.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikId;

    /**
     * NOTA_ODPLATNOSC.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydrukuId;

    /**
     * NOTA_ODPLATNOSC.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * NOTA_ODPLATNOSC.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * NOTA_ODPLATNOSC.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypNotyOdplatnosc typ;

    /**
     * NOTA_ODPLATNOSC.SZABLON_WYDRUKU_2_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydruku2Id;

    /**
     * NOTA_ODPLATNOSC.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusNotyOdplatnosc status;

    /**
     * NOTA_ODPLATNOSC.RODZAJ_ZADLUZENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajZadluzenia rodzajZadluzenia;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return NOTA_ODPLATNOSC.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * NOTA_ODPLATNOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return NOTA_ODPLATNOSC.INSTYTUCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * NOTA_ODPLATNOSC.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return NOTA_ODPLATNOSC.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * NOTA_ODPLATNOSC.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return NOTA_ODPLATNOSC.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * NOTA_ODPLATNOSC.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return NOTA_ODPLATNOSC.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * NOTA_ODPLATNOSC.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return NOTA_ODPLATNOSC.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * NOTA_ODPLATNOSC.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return NOTA_ODPLATNOSC.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypNotyOdplatnosc getTyp() {
        return typ;
    }

    /**
     * NOTA_ODPLATNOSC.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypNotyOdplatnosc typ) {
        this.typ = typ;
    }

    /**
     * @return NOTA_ODPLATNOSC.SZABLON_WYDRUKU_2_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydruku2Id() {
        return szablonWydruku2Id;
    }

    /**
     * NOTA_ODPLATNOSC.SZABLON_WYDRUKU_2_ID
     *
     * @param szablonWydruku2Id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydruku2Id(Long szablonWydruku2Id) {
        this.szablonWydruku2Id = szablonWydruku2Id;
    }

    /**
     * @return NOTA_ODPLATNOSC.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusNotyOdplatnosc getStatus() {
        return status;
    }

    /**
     * NOTA_ODPLATNOSC.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusNotyOdplatnosc status) {
        this.status = status;
    }

    /**
     * @return NOTA_ODPLATNOSC.RODZAJ_ZADLUZENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajZadluzenia getRodzajZadluzenia() {
        return rodzajZadluzenia;
    }

    /**
     * NOTA_ODPLATNOSC.RODZAJ_ZADLUZENIA
     *
     * @param rodzajZadluzenia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzajZadluzenia(RodzajZadluzenia rodzajZadluzenia) {
        this.rodzajZadluzenia = rodzajZadluzenia;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        NotaOdplatnosc other = (NotaOdplatnosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getSzablonWydruku2Id() == null ? other.getSzablonWydruku2Id() == null : this.getSzablonWydruku2Id().equals(other.getSzablonWydruku2Id()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getRodzajZadluzenia() == null ? other.getRodzajZadluzenia() == null : this.getRodzajZadluzenia().equals(other.getRodzajZadluzenia()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getSzablonWydruku2Id() == null) ? 0 : getSzablonWydruku2Id().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getRodzajZadluzenia() == null) ? 0 : getRodzajZadluzenia().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", data=").append(data);
        sb.append(", nr=").append(nr);
        sb.append(", typ=").append(typ);
        sb.append(", szablonWydruku2Id=").append(szablonWydruku2Id);
        sb.append(", status=").append(status);
        sb.append(", rodzajZadluzenia=").append(rodzajZadluzenia);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/NotaOdplatnosc.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.RodzajZadluzenia;
import pl.topteam.dps.enums.StatusNotyOdplatnosc;
import pl.topteam.dps.enums.TypNotyOdplatnosc;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class NotaOdplatnosc extends GenericDPSObject {
    /**
     * NOTA_ODPLATNOSC.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * NOTA_ODPLATNOSC.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long instytucjaId;

    /**
     * NOTA_ODPLATNOSC.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikId;

    /**
     * NOTA_ODPLATNOSC.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydrukuId;

    /**
     * NOTA_ODPLATNOSC.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * NOTA_ODPLATNOSC.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * NOTA_ODPLATNOSC.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypNotyOdplatnosc typ;

    /**
     * NOTA_ODPLATNOSC.SZABLON_WYDRUKU_2_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydruku2Id;

    /**
     * NOTA_ODPLATNOSC.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusNotyOdplatnosc status;

    /**
     * NOTA_ODPLATNOSC.RODZAJ_ZADLUZENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajZadluzenia rodzajZadluzenia;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return NOTA_ODPLATNOSC.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * NOTA_ODPLATNOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return NOTA_ODPLATNOSC.INSTYTUCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * NOTA_ODPLATNOSC.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return NOTA_ODPLATNOSC.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * NOTA_ODPLATNOSC.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return NOTA_ODPLATNOSC.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * NOTA_ODPLATNOSC.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return NOTA_ODPLATNOSC.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * NOTA_ODPLATNOSC.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return NOTA_ODPLATNOSC.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * NOTA_ODPLATNOSC.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return NOTA_ODPLATNOSC.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypNotyOdplatnosc getTyp() {
        return typ;
    }

    /**
     * NOTA_ODPLATNOSC.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypNotyOdplatnosc typ) {
        this.typ = typ;
    }

    /**
     * @return NOTA_ODPLATNOSC.SZABLON_WYDRUKU_2_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydruku2Id() {
        return szablonWydruku2Id;
    }

    /**
     * NOTA_ODPLATNOSC.SZABLON_WYDRUKU_2_ID
     *
     * @param szablonWydruku2Id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydruku2Id(Long szablonWydruku2Id) {
        this.szablonWydruku2Id = szablonWydruku2Id;
    }

    /**
     * @return NOTA_ODPLATNOSC.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusNotyOdplatnosc getStatus() {
        return status;
    }

    /**
     * NOTA_ODPLATNOSC.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusNotyOdplatnosc status) {
        this.status = status;
    }

    /**
     * @return NOTA_ODPLATNOSC.RODZAJ_ZADLUZENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajZadluzenia getRodzajZadluzenia() {
        return rodzajZadluzenia;
    }

    /**
     * NOTA_ODPLATNOSC.RODZAJ_ZADLUZENIA
     *
     * @param rodzajZadluzenia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzajZadluzenia(RodzajZadluzenia rodzajZadluzenia) {
        this.rodzajZadluzenia = rodzajZadluzenia;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        NotaOdplatnosc other = (NotaOdplatnosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getSzablonWydruku2Id() == null ? other.getSzablonWydruku2Id() == null : this.getSzablonWydruku2Id().equals(other.getSzablonWydruku2Id()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getRodzajZadluzenia() == null ? other.getRodzajZadluzenia() == null : this.getRodzajZadluzenia().equals(other.getRodzajZadluzenia()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getSzablonWydruku2Id() == null) ? 0 : getSzablonWydruku2Id().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getRodzajZadluzenia() == null) ? 0 : getRodzajZadluzenia().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", data=").append(data);
        sb.append(", nr=").append(nr);
        sb.append(", typ=").append(typ);
        sb.append(", szablonWydruku2Id=").append(szablonWydruku2Id);
        sb.append(", status=").append(status);
        sb.append(", rodzajZadluzenia=").append(rodzajZadluzenia);
        sb.append("]");
        return sb.toString();
    }
}
